@@ -1,4 +1,8 @@
 #!/usr/bin/python
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 #
 # Copyright 2016-2017 David Steele <steele@debian.org>
@@ -93,11 +97,6 @@ def interpreter():
 
         print_cmd_prompts(state, connection, points)
 
-        try:
-            input = raw_input
-        except NameError:
-            pass
-
         cmd = input("command?: ")
 
         index = int_value(cmd)
