@@ -1,11 +1,15 @@
 #!/usr/bin/python
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 
 import os
 import logging
 from logging.handlers import TimedRotatingFileHandler
-import persist
-import config
+from comitup import persist
+from comitup import config
 import random
 import argparse
 import sys
@@ -15,10 +19,10 @@ from gi.repository.GLib import MainLoop
 from dbus.mainloop.glib import DBusGMainLoop
 DBusGMainLoop(set_as_default=True)
 
-import statemgr     # noqa
-import webmgr       # noqa
-import iptmgr       # noqa
-import wificheck    # noqa
+from comitup import statemgr     # noqa
+from comitup import webmgr       # noqa
+from comitup import iptmgr       # noqa
+from comitup import wificheck    # noqa
 
 PERSIST_PATH = "/var/lib/comitup/comitup.json"
 CONF_PATH = "/etc/comitup.conf"
