@@ -1,4 +1,8 @@
 
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 #
 # Copyright 2017 David Steele <steele@debian.org>
 # This file is part of comitup
@@ -8,8 +12,8 @@
 
 import logging
 import subprocess
-import modemgr
-import nm
+from comitup import modemgr
+from comitup import nm
 
 
 start_cmds = [
