@@ -1,4 +1,8 @@
 #!/usr/bin/python
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 #
 # Copyright 2016-2017 David Steele <steele@debian.org>
@@ -7,12 +11,11 @@
 # or later
 #
 
-import avahi
 import dbus
-from encodings.idna import ToASCII
 import socket
 import logging
-import nm
+from comitup import nm
+import subprocess
 
 log = logging.getLogger('comitup')
 
@@ -22,40 +25,43 @@ CLASS_IN = 0x01
 TYPE_A = 0x01
 TTL = 5
 
+DBUS_NAME = 'org.freedesktop.Avahi'
+DBUS_PATH_SERVER = '/'
+DBUS_INTERFACE_SERVER = 'org.freedesktop.Avahi.Server'
+DBUS_INTERFACE_ENTRY_GROUP = 'org.freedesktop.Avahi.EntryGroup'
+PROTO_INET = 0
+
 group = None
 
-
 # functions
 
+
 def establish_group():
     global group
 
     bus = dbus.SystemBus()
 
     server = dbus.Interface(
-            bus.get_object(avahi.DBUS_NAME, avahi.DBUS_PATH_SERVER),
-            avahi.DBUS_INTERFACE_SERVER
+            bus.get_object(DBUS_NAME, DBUS_PATH_SERVER),
+            DBUS_INTERFACE_SERVER
     )
 
     group = dbus.Interface(
-            bus.get_object(avahi.DBUS_NAME, server.EntryGroupNew()),
-            avahi.DBUS_INTERFACE_ENTRY_GROUP
+            bus.get_object(DBUS_NAME, server.EntryGroupNew()),
+            DBUS_INTERFACE_ENTRY_GROUP
     )
 
 
 def encode_dns(name):
-    out = []
-    for part in name.split('.'):
-        if len(part) == 0:
-            continue
-        out.append(ToASCII(part))
-    return '.'.join(out)
+    components = [x for x in name.split('.') if len(x) > 0]
+    fixed_name = '.'.join(components)
+    return fixed_name.encode('ascii')
 
 
 def make_a_record(host, devindex, addr):
     group.AddRecord(
         devindex,
-        avahi.PROTO_INET,
+        PROTO_INET,
         dbus.UInt32(0),
         encode_dns(host),
         CLASS_IN,
@@ -65,6 +71,17 @@ def make_a_record(host, devindex, addr):
     )
 
 
+def string_to_txt_array(strng):
+    if strng:
+        return [dbus.Byte(x) for x in strng.encode()]
+    else:
+        return strng
+
+
+def string_array_to_txt_array(txt_array):
+    return [string_to_txt_array(x) for x in txt_array]
+
+
 def add_service(host, devindex, addr):
     name = host
     if '.local' in name:
@@ -72,15 +89,15 @@ def add_service(host, devindex, addr):
 
     group.AddService(
         devindex,
-        avahi.PROTO_INET,
+        PROTO_INET,
         dbus.UInt32(0),
         name,
         "_workstation._tcp",
         "",
         host,
         dbus.UInt16(9),
-        avahi.string_array_to_txt_array([
-            "hostname=%s" % host,
+        string_array_to_txt_array([
+            "hostname=%s" % host.encode(),
             "ipaddr=%s" % addr,
             "comitup-home=https://davesteele.github.io/comitup/",
         ])
@@ -96,19 +113,35 @@ def clear_entries():
     establish_group()
 
 
+def get_interface_mapping():
+    mapping = {}
+
+    for line in subprocess.check_output("ip addr".split()).decode().split('\n'):
+        try:
+            asc_index, name = line.split(": ")[0:2]
+            mapping[name] = int(asc_index)
+        except ValueError:
+            pass
+
+    return mapping
+
+
 def add_hosts(hosts):
     establish_group()
+    int_mapping = get_interface_mapping()
 
-    i = 0
     for device in nm.get_devices():
-        i += 1
         name = nm.device_name(device)
         addr = nm.get_active_ip(device)
-        if (name in nm.get_phys_dev_names()) and addr:
-            for host in hosts:
-                make_a_record(host, i, addr)
+        if (name in nm.get_phys_dev_names() \
+            and name in int_mapping \
+            and addr):
 
-            add_service(hosts[0], i, addr)
+            index = int_mapping[name]
+            for host in hosts:
+                make_a_record(host, index, addr)
+
+            add_service(hosts[0], index, addr)
 
     group.Commit()
 
