@@ -1,4 +1,8 @@
 #!/usr/bin/python
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 #
 # Copyright 2017 David Steele <steele@debian.org>
@@ -7,8 +11,8 @@
 # or later
 #
 
-import nm
-import config
+from comitup import nm
+from comitup import config
 
 
 SINGLE_MODE = "single"
