@@ -1,4 +1,8 @@
 #!/usr/bin/python
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 #
 # Copyright 2016-2017 David Steele <steele@debian.org>
@@ -17,8 +21,8 @@ import logging
 if __name__ == '__main__':
     DBusGMainLoop(set_as_default=True)
 
-import nm       # noqa
-import modemgr  # noqa
+from comitup import nm       # noqa
+from comitup import modemgr  # noqa
 
 
 #
