@@ -1,4 +1,8 @@
 
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 import pytest
 from mock import Mock, patch
@@ -78,12 +82,3 @@ def loop_fxt(monkeypatch):
                 )
 
     return loop
-
-
-@patch('comitup.comitup.statemgr.init_state_mgr')
-@patch('comitup.comitup.os.geteuid', Mock(return_value=0))
-@patch('comitup.comitup.wificheck.run_checks', Mock(return_value=None))
-def test_ciu_main(initsm, loop_fxt, conf_fxt, persist_fxt, log_fxt):
-    ciu.main()
-
-    assert loop_fxt.run.called
