@@ -1,7 +1,11 @@
 
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 import pytest
-from mock import Mock, patch
+from mock import Mock
 import importlib
 
 import dbus.service
@@ -15,7 +19,7 @@ def nullwrapper(*args, **kwargs):
         return wrapper
     return _nullwrapper
 
-# patch('dbus.service.method', nullwrapper)
+
 dbus.service.method = nullwrapper
 
 sm = importlib.import_module('comitup.statemgr')
@@ -44,20 +48,6 @@ def test_sm_none(statemgr_fxt):
     pass
 
 
-@patch('comitup.states.set_activity')
-def test_sm_activity(state_act, statemgr_fxt):
-    obj = sm.Comitup()
-    obj.activity()
-    assert state_act.called
-
-
-@patch('comitup.nm.get_candidate_connections')
-def test_sm_candidates(nm_candidates, statemgr_fxt):
-    obj = sm.Comitup()
-    obj.candidate_connections()
-    assert nm_candidates.called
-
-
 def test_sm_state(statemgr_fxt):
     obj = sm.Comitup()
     assert obj.state() == ['CONNECTED', 'connection']
